Class: Wavesync::Transport::Filesystem
- Inherits:
-
Object
- Object
- Wavesync::Transport::Filesystem
- Defined in:
- lib/wavesync/transport/filesystem.rb
Instance Attribute Summary collapse
-
#working_directory ⇒ Object
readonly
: String.
Instance Method Summary collapse
-
#begin_push! ⇒ Object
: () -> void.
-
#commit! ⇒ Object
: () ?{ (Integer, Integer, String) -> void } -> void.
-
#finish_push! ⇒ Object
: () -> void.
-
#initialize(device_config) ⇒ Filesystem
constructor
: ({ name: String, model: String, path: String, transport: String?, mp3_bitrate: Integer } device_config) -> void.
-
#prepare! ⇒ Object
: () ?{ (Integer, Integer, String) -> void } -> void.
-
#push_file!(relative_path) ⇒ Object
: (String relative_path) -> void.
Constructor Details
#initialize(device_config) ⇒ Filesystem
: ({ name: String, model: String, path: String, transport: String?, mp3_bitrate: Integer } device_config) -> void
10 11 12 |
# File 'lib/wavesync/transport/filesystem.rb', line 10 def initialize(device_config) @working_directory = device_config[:path] end |
Instance Attribute Details
#working_directory ⇒ Object (readonly)
: String
7 8 9 |
# File 'lib/wavesync/transport/filesystem.rb', line 7 def working_directory @working_directory end |
Instance Method Details
#begin_push! ⇒ Object
: () -> void
27 |
# File 'lib/wavesync/transport/filesystem.rb', line 27 def begin_push!; end |
#commit! ⇒ Object
: () ?{ (Integer, Integer, String) -> void } -> void
21 22 23 24 |
# File 'lib/wavesync/transport/filesystem.rb', line 21 def commit! # Filesystem destinations are written to directly during sync, so there # is nothing to commit here. end |
#finish_push! ⇒ Object
: () -> void
33 |
# File 'lib/wavesync/transport/filesystem.rb', line 33 def finish_push!; end |
#prepare! ⇒ Object
: () ?{ (Integer, Integer, String) -> void } -> void
15 16 17 18 |
# File 'lib/wavesync/transport/filesystem.rb', line 15 def prepare! # Filesystem destinations expose live device contents directly, so # there is nothing to pull beforehand. end |
#push_file!(relative_path) ⇒ Object
: (String relative_path) -> void
30 |
# File 'lib/wavesync/transport/filesystem.rb', line 30 def push_file!(relative_path); end |